@@ -15,7 +15,7 @@
     @mkdir ($result_path."/".$result_name);
     // Files
     
-    $command = "diff -x*png -x*.ini* -x*rrd -x*log -x*sql -Nru ".
+    $command = "diff -x*png -x*.ini* -x*rrd -x*log -x*sql -xjffnms.conf* -Nru ".
 	    "$base_installation $current_installation > $result_path/$result_name/$result_name.patch";
 
     exec ($command,$result);
@@ -53,7 +53,7 @@ $tables = array (
 " autodiscovery    ",-1,
 " hosts_config_types",-1,
 " tools          ",-1,
-" profiles_values  ",299,
+" profiles_values  ",301,
 " profiles_options ",-1,
 " triggers   	   ",-1,
 " triggers_rules   ",-1,
