@@ -28,99 +28,128 @@ function truncate_counter (&$value) {
     if ($max_pass >= 1) $value = floor($value - $max_less);
 }
 
-
 function create_rama ($oid,$k,$data,$deep,&$tree) {
     if (!is_numeric(current(array_keys($data)))) $data = array_values ($data);
 
-    //echo "rama $oid -deep $deep -k $k\n";
-    //var_dump($data);
-
     while (list ($k1,$item) = each ($data)) {
 	if (is_array($item)) create_rama ("$oid.$k",$k1,$item,++$deep,$tree);
 	else 
-	    if ($deep==0) {
+	    if ($deep==0)
 		$tree["$oid.$k.$k1"]=$item;
-	        //echo "B: $oid - $k - $k1 - $item\n";
-	    } else {
+	    else 
 		$tree["$oid.$k1.$k"]=$item;
-	        //echo "C: $oid - $k1 - $k - $item\n";
-	    }
     }
 }
 
 function create_tree ($oid,$data,&$tree) {
+    $start = time();
+    
     $data = array_values($data);
-    //echo "tree\n";
+
     foreach ($data as $k=>$v) {
 	if (is_array($v)) 
 	    create_rama ($oid,$k,$v,0,$tree);
-	else {
+	else 
 	    $tree["$oid.$k"]=$v;
-	    //echo "A: $oid.$k - $v\n";
-	}
     }
-    return $tree;
+
+    uksort($tree,"oid_cmp");
+    reset ($tree);
+    
+    return time()-$start;
 }
 
 function secho ($oid,$var = NULL) {
-    $out .= "$oid\n";
-    if (!is_null($var)){ 
-	if (is_numeric($var)) $out .="integer\n";
-	else $out.= "string\n";
 
-        $out.="$var\n";
+    $out .= "$oid\n";
+
+    if (!is_null($var)){ 
+
+	$out .= ((is_numeric($var))?"integer":"string")."\n";
+        $out .= $var."\n";
     }
-    echo $out;
+    
+    return $out;
 }
 
 function walk_tree ($start, &$tree) {
     $show_next = 0;
 
+    reset ($tree);
     while (list ($k,$v) = each ($tree)) {
 
-	if (($show_next == 1) || (preg_match("/^$start\S+/",$k,$aux))) {
-	    secho ($k,$v);
-	    break;
-	}
+	if (($show_next == 1) || ((strpos($k, $start)===0) && ($k!==$start)))
+	    return secho ($k,$v);
 	
 	if ($k===$start) 
 	    $show_next = 1;
     }
+    
+    return "NONE\n";
 }
 
-
-list ($myself, $tree_to_use, $base, $oper, $oid)  = $_SERVER["argv"];
-
-$trees = array("tc","iptables");
-
-if (in_array($tree_to_use,$trees)) {
-    $tree = array();
     
-    $tree_filename = dirname($myself)."/".$tree_to_use.".state";
-    $generate_again = 1;
+    list ($myself, $tree_to_use, $base, $tree_refresh)  = $_SERVER["argv"];
+
+    if (!is_numeric($tree_refresh)) 
+	$tree_refresh = (1*60);
+
+    include ($tree_to_use.".inc.php");
+
+    $in = fopen("php://stdin","r");
+    $step = 0;
     
-    if ((file_exists($tree_filename)===true) && ((time() - filemtime($tree_filename)) < 60)) { //if tree is less than 60 seconds old
-	$generate_again = 0; 	//don't generate it again
-	$tree = unserialize(join("",file($tree_filename))); //load it from file
-    }
-    
-    if ($generate_again == 1) {
-	include ("$tree_to_use.inc.php");
-        create_tree ($base,call_user_func("tree_$tree_to_use"),$tree);
-	uksort($tree,"oid_cmp");
-	reset ($tree);
+    while ($line = fgets($in)) {
+
+	$line = trim($line); 
 	
-	//save tree
-	$fp = fopen($tree_filename,"w+");
-	fputs($fp,serialize($tree));
-	fclose($fp);
+	if ($tree_time+$tree_refresh < time()) {
+	    $tree = array();
+	    $creation_time = create_tree ($base,call_user_func("tree_".$tree_to_use),$tree);
+	    $tree_time = time();
+	}
+	
+	switch ($line) {
+	
+	    case "DEBUG":
+		print_r($tree);
+		echo "Tree creation time: $creation_time, Created ".(time()-$tree_time)." seconds ago.\n";
+	    break;
+	    
+	    case "PING":
+		$result = "PONG\n";
+		$step = 0;
+	    break;
+
+	    default:
+		
+		switch ($step) {		
+		    case 0: $oper = $line; $step = 1; break;
+		    case 1: $oid  = $line; $step = 2; break;
+		}
+
+		if ($step==2) {
+		    $step = 0;
+		
+		    switch ($oper) {
+			case "getnext": 
+	    		    $result = walk_tree ($oid, $tree); 
+			    break;
+
+			case "get": 
+		    	    if (isset($tree[$oid])) 
+			    $result = secho ($oid,$tree[$oid]); 
+			break;
+		    }
+		    
+		    if (!isset($result)) $result = "NONE\n";
+		}
+	} 
+	
+	if (isset($result)) {
+	    echo $result;
+	    unset ($result);
+	}
     }
-    
-    switch ($oper) {
-	case "-n" : walk_tree ($oid,$tree); break;
-	case "-g" : if (isset($tree[$oid])) secho ($oid,$tree[$oid]); break;
-	case "debug" : print_r ($tree); echo "Gen: $generate_again\n"; break;
-    }
-}
 
 ?>
