@@ -37,7 +37,7 @@ $tables = Array (
 " alarm_states     ",-1,
 " severity         ",-1,
 " syslog_types     ",-1,
-" traps_types      ",-1,
+" trap_receivers   ",-1,
 " types            ",-1,
 " slas             ",-1,
 " slas_cond        ",-1,
