@@ -14,6 +14,19 @@ UPDATE interface_types set autodiscovery_parameters_new = autodiscovery_paramete
 ALTER TABLE interface_types DROP COLUMN autodiscovery_parameters;
 ALTER TABLE interface_types RENAME COLUMN autodiscovery_parameters_new to autodiscovery_parameters;
 
+ALTER TABLE `slas_cond` CHANGE `condition` `cond` CHAR( 250 ) NOT NULL;
+
+
+
+
+ALTER TABLE `events` CHANGE COLUMN `interface` `interface` char(150) NOT NULL; # was char(40) NOT NULL default ''
+ALTER TABLE `hosts` CHANGE COLUMN `name` `name` char(255) NOT NULL; # was char(30) NOT NULL default ''
+ALTER TABLE `interfaces_values` CHANGE COLUMN `value` `value` varchar(3000) NOT NULL; # was char(250) NOT NULL default ''
+ALTER TABLE `nad_hosts` CHANGE COLUMN `description` `description` varchar(3000) NOT NULL; # was char(250) NOT NULL default ''
+ALTER TABLE `slas_cond` CHANGE `condition` `cond` CHAR( 250 ) NOT NULL;
+ALTER TABLE `slas` CHANGE `state` `state` INT( 10 ) NOT NULL DEFAULT '3';
+
+
 */
 
     $types["tinyint(1)"]="int2";
@@ -26,6 +39,9 @@ ALTER TABLE interface_types RENAME COLUMN autodiscovery_parameters_new to autodi
     $types["char(10)"]="varchar(10)";
     $types["char(60)"]="varchar(60)";
     $types["char(100)"]="varchar(100)";
+    $types["char(150)"]="varchar(150)";
+    $types["char(255)"]="varchar(255)";
+    $types["varchar(3000)"]="varchar(3000)";
     $types["varchar(30)"]="varchar(30)";
     $types["char(250)"]="varchar(250)";
     $types["longtext"]="text";    
@@ -36,21 +52,25 @@ ALTER TABLE interface_types RENAME COLUMN autodiscovery_parameters_new to autodi
     while ($line = fgets($fp)) {
 	$new_sql="";
 	//echo $line;
-	
+	$line = str_replace("`","", trim($line));
+	//var_dump($line);
 	//CHANGE
 	if (	preg_match("/ALTER TABLE (\S+) CHANGE COLUMN (\S+) (\S+) (\S.+) NOT NULL default (\S+);/",$line,$parts) ||
 		preg_match("/ALTER TABLE (\S+) CHANGE COLUMN (\S+) (\S+) (\S.+) DEFAULT (\S+) NOT NULL;/",$line,$parts)	||
-		preg_match("/ALTER TABLE (\S+) CHANGE COLUMN (\S+) (\S+) (\S.+) NOT NULL;/",$line,$parts)
+		preg_match("/ALTER TABLE (\S+) CHANGE COLUMN (\S+) (\S+) (\S.+) NOT NULL;/",$line,$parts) ||
+                preg_match("/ALTER TABLE (\S+) CHANGE (\S+) (\S+) (\S.+) NOT NULL;/",$line,$parts) ||
+                preg_match("/ALTER TABLE (\S+) CHANGE (\S+) (\S+) (\S.+) NOT NULL DEFAULT (\S+);/i",$line,$parts)
+
 		) {
 	    //var_dump($parts);
 	
 	    $table = $parts[1];
 	    $old_field = $parts[2];
 	    $new_field = $parts[3];
-	    $type = $parts[4];
+	    $req_type = $parts[4];
 	    $def = $parts[5];
 	    
-	    $type = $types[str_replace(" ","",strtolower($type))];
+	    $type = $types[str_replace(" ","",strtolower($req_type))];
 	    
 	    if ($type!=NULL) {
 		$temp_field = $new_field."_new_convert";
@@ -60,7 +80,8 @@ ALTER TABLE interface_types RENAME COLUMN autodiscovery_parameters_new to autodi
 		$new_sql .=	"UPDATE $table set $temp_field = $old_field;\n";
 	        $new_sql .=	"ALTER TABLE $table DROP COLUMN $old_field CASCADE;\n";
 	        $new_sql .=	"ALTER TABLE $table RENAME COLUMN $temp_field to $new_field;\n";
-	    }
+	    } else
+		$new_sql = "BAD TYPE: ".$req_type." - ".$line."\n";
 	}
 
 	//ADD
@@ -139,7 +160,7 @@ ALTER TABLE interface_types RENAME COLUMN autodiscovery_parameters_new to autodi
 	
 	if (isset($new_sql)) {
 	    if (empty($new_sql)) 
-		$new_sql = $line; //if it was not converted show the old line, no parsing required
+		$new_sql = $line."\n"; //if it was not converted show the old line, no parsing required
 	    echo $new_sql;	
 	}
     }
