@@ -33,6 +33,7 @@
     $file = $_SERVER["argv"][1];
     if (!$file) $file = "php://stdin";
     
+    $diffs = array();
     $in = fopen($file,"r");
     $i=0;    
     while ($data = fgets($in)) 
@@ -40,6 +41,7 @@
 	    $diffs[]=$data;
     fclose($in);
     
+    
     $records = array();
     foreach ($diffs as $diff) {
 	preg_match("/(\S)INSERT INTO (\S+) \((\S.+)\) VALUES \((\S.+)\);/",$diff,$parts);
@@ -47,6 +49,7 @@
 	$fields = explode(",",$parts[3]);
 	$values = explode(",",$parts[4]);
 	$values = sql_values($parts[4]);
+	//var_dump($values);
 	
 	$type=$parts[1];
 	
@@ -65,6 +68,7 @@
 	$diffs[$rec["table"]]["records"][$rec["id"]][$rec["type"]]=$rec["values"];
     }
     unset ($records);
+    //var_dump($diffs);
     
     if (is_array($diffs))
     foreach ($diffs as $table=>$data) {
