@@ -1,10 +1,19 @@
 <?
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
     //Send eMail
 
     function action_email ($data) {
 	extract($data);
 	//debug ($data);
 
+	if (!function_exists("mail")) {
+	    logger("Mail function does not exists.\n");
+	    return 0;
+	}
+
 	$from = $parameters[from];
 	$to = $parameters[to];
 	$subject = $parameters[subject];
@@ -29,11 +38,11 @@
 	}
 	
 	if (is_array($interface)) 
-	    $content[interface]=	"Interface:\t".
+	    $content["interface"]=	"Interface:\t".
 					$interface[type_descripton]." ".
 					$interface[host_name]." ".
 					$interface[zone_shortname]." ".
-					$interface[interface]." ".
+					$interface["interface"]." ".
 					$interface[client_name]." ".
 					$interface[description]." ".
 					"\n";
@@ -61,8 +70,9 @@
 	
 	if ($short) $body = str_replace("\t"," ",$body);
 
-	if ((strpos($to,"@") > 1) && $subject && $body && $headers) 
+	if ((strpos($to,"@") > 1) && $subject && $body && $headers)
 	    $result = mail($to,$subject,$body,$headers,"-f$from");
+	    //debug (array($to,$subject,$body,$headers,"-f$from"));
 	else 
 	    $result = 0;
 	    
