@@ -39,7 +39,7 @@
 
 	$query_sla="
 	    SELECT 
-		slas_cond.condition, slas_cond.description, slas_cond.event,
+		slas_cond.cond, slas_cond.description, slas_cond.event,
 		slas_sla_cond.show_in_result, slas_cond.variable_show, slas_cond.variable_show_info
 	    FROM 
 		slas_cond, slas_sla_cond
@@ -51,7 +51,7 @@
 	
 	while ($sla = db_fetch_array($result_sla)) {
 
-	    $sla_cond 			= replace_vars(trim($sla["condition"]),$values);
+	    $sla_cond 			= replace_vars(trim($sla["cond"]),$values);
 	    $sla_variable_show 		= replace_vars(trim($sla["variable_show"]),$values);
 	    $sla_variable_show_info 	= replace_vars(trim($sla["variable_show_info"]),$values);
 	    $sla["event"]		= replace_vars(trim($sla["event"]),$values);
