@@ -85,7 +85,8 @@
 	    
 	    if  (
 		(ip_same_network($net, $private_net, bitsmask_to_mask($private_mask))) ||	// base net is the same network as a private net
-		(ip_same_network($net, "0.0.0.0", bitsmask_to_mask($net_mask)))			// base net is 0.0.0.0
+		(ip_same_network($net, "0.0.0.0", bitsmask_to_mask($net_mask)))	||		// base net is 0.0.0.0
+		(ip_same_network($net, "0.0.0.0", bitsmask_to_mask(24)))			// base net is 0.0.0.0
 		)
 		return true;
 	}
@@ -138,7 +139,6 @@
 		
 		$host_ip_parts = explode(".",$host_ip);
 		
-				
 		if (($host_ip_parts[3]!=0) && ($host_ip_parts[3]!=255)) {
 		    if ($parts[3]=="Up") {
 			$hosts_up++;
@@ -192,7 +192,7 @@
 	while ((list (, $comm) = each ($communities)) && (!$snmp_name))
 	    
 	    if (($snmp_name = snmp_get($host_ip, $comm, $system_name_oid, 1))!==false) {
-
+		
 		$log =  "N ".str_pad($net["id"], 4)." : H ".str_pad($host_id,3)." : ";
 		logger ($log." Has SNMP $comm - $snmp_name\n");
 
@@ -204,8 +204,11 @@
 
 		    // Create IPs Table
 		    foreach ($snmp_ips_data as $key=>$aux_ip) {
-			list(,$aux_ip) = explode (" ",$aux_ip);
-
+			$aux_ip = trim($aux_ip);
+			
+			if (strpos(" ", $aux_ip)!==false)
+			    list(,$aux_ip) = explode (" ",$aux_ip);
+			
 			if (!in_array($aux_ip,$invalid_ips)) {
 
 			    if ($aux_ip!=$host_ip) 					// If IP is different than the host IP
@@ -225,7 +228,11 @@
 		    // Populate the IPs table with Mask and Type data
 		    foreach ($host_ips as $aux_ip=>$ipd) {
 	
-			list(,$aux_mask) = explode (" ",$snmp_mask_data[$ipd["pos"]]);
+			if (strpos(" ", $aux_mask)!==false)
+			    list(,$aux_mask) = explode (" ",$snmp_mask_data[$ipd["pos"]]);
+			else
+			    $aux_mask = $snmp_mask_data[$ipd["pos"]];
+			    
 			if (empty($aux_mask)) $aux_mask = "255.255.255.0"; // Fix for broken IP-MIB implementations
 					
 			$if_index = $snmp_int_data[$ipd["pos"]];
@@ -326,7 +333,7 @@
 	    $net_bit = $ip_bit & $mask_bit;
 	    $net = ip_to_str2 ($net_bit);
 
-	    if ($net != "127.0.0.0") {
+	    if (($net != "127.0.0.0") && ($net!="0.0.0.0")) {
 		$oper_status = 0;
 
 		$mask_prefix = ip_to_bitsmask ($mask_bit);
@@ -347,10 +354,15 @@
 		    "via NET_ID $parent_net, Deep $deep\n");
 		*/
 		
-		if (!isset($networks[$aux]))
-		    return db_insert("nad_networks",array("network"=>$aux, "deep"=>$deep, "parent"=>$parent_net, 
-			"oper_status"=>$oper_status, "seed"=>$seed_id, "oper_status_changed"=>time(), "id"=>$id));
-		else
+		if (!isset($networks[$aux])) {
+		
+		    $fields = array("network"=>$aux, "deep"=>$deep, "parent"=>$parent_net, 
+			"oper_status"=>$oper_status, "seed"=>$seed_id, "oper_status_changed"=>time());
+
+		    if ($id!==NULL) $fields["id"] = $id;
+	
+		    return db_insert("nad_networks",$fields);
+		} else
 		    return $networks[$aux]["id"];	// return the network id
 	    }
     }
@@ -554,7 +566,7 @@
 		if (($net_data["oper_status"] == 2) && 					// if its Running
 		    !isset($pending_items[$network])) {					// and its not in the pending list
 		
-		    nad_network_status ($net_data["id"], 5); 				// mark it as error
+		    //nad_network_status ($net_data["id"], 5); 				// mark it as error
 		    logger("Changed Network $network to Error, because it was hanged running\n");
 		}
 
