@@ -12,9 +12,9 @@ function backend_verify_interface_number($options,$result) {
     if (($result!=$options[$index_field]) && (!empty($result)) && ($result!="-1")) { //if valid result and result different than older value
 
 	$data = array($index_field=>$result);
-	$result = adm_interfaces_update($options["interface_id"],$data);
+	adm_interfaces_update($options["interface_id"],$data);
 	
-	return "$index_field changed";
+	return "$index_field changed ".$options[$index_field]." -> ".$result;
     } else 
 	return "$index_field not changed";
 }
