@@ -20,18 +20,18 @@ if ($raw_days > 0) {
     logger ("Cleaning up raw messages older than $dtdelete ($raw_days days)...\n");
 
     // Traps cleanup
-    $query_traps = "select id from traps where date <= '$dtdelete'";
+    $query_traps = "select id from traps where date <= ".$period;
     $result_traps = db_query ($query_traps) or die ("Query failed - TC1 - ".db_error());
     
     $result_del_varbinds = 0;
     while ($rows_traps = db_fetch_array($result_traps)) {
         $id = $rows_traps['id'];
 
-        $query="delete from traps_varbinds where trapid=$id";
+        $query="delete from traps_varbinds where trapid = ".$id;
         $result_del_varbinds = db_query ($query) or die ("Query failed: TC2 - Delete varbinds - ".db_error());
     }
 
-    $query = "delete from traps where date <= '$dtdelete'";
+    $query = "delete from traps where date <= ".$period;
     $result_del_traps = db_query ($query) or die ("Query failed: TC3 - Delete traps - ".db_error());
     logger ("Cleanup of traps/traps_varbinds tables finished... ($result_del_traps, $result_del_varbinds)\n");
     // END Traps cleanup
