@@ -19,6 +19,8 @@
     if (is_process_running(NULL,2) === false) {	//check if a process named as myself is already running (one instance is me)
 
 	detach();
+	
+	include_once("consolidate/traps.php");
 
 	logger ("Consolidator Starting...\n");
 	do {
@@ -28,7 +30,10 @@
 	    //FIXME replace this calls with functions
 	    include("consolidate/syslog.php"); flush();
 	    include("consolidate/tacacs.php"); flush();	
-	    include("consolidate/traps.php"); flush();
+	    
+	    consolidate_traps();
+	    flush();
+	    
 	    include("consolidate/events.php"); flush();
 	    include("consolidate/events_latest.php"); flush();
 	    include("consolidate/alarms.php"); flush();
