@@ -1,21 +1,7 @@
 <?
-/* Events Analizer
- * Copyright (C) <2002> Javier Szyszlican <javier@szysz.com>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+/* Events Analizer is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
  */
 
     $query_events = "
@@ -34,9 +20,7 @@
 	GROUP BY    	events.id, events.date, events.type, alarm_states.state,
 			interfaces.id, alarm_states.id, types.alarm_up, types.alarm_duration
 
-	ORDER BY	events.date asc, events.id asc, interfaces.id\n".
-	
-	" LIMIT	0,100"; //Space is needed
+	ORDER BY	events.date asc, events.id asc, interfaces.id";
 
     //var_dump ($query_events);
     $result_events = db_query ($query_events) or die ("Query failed - consolidate events - ".db_error());
