@@ -1,10 +1,14 @@
 <?
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
     function discovery_bgp_peers ($ip,$rocommunity,$hostid,$param) {
 
 	    $bgp_interfaces = array();
 
 	    if ($ip && $hostid && $rocommunity)  
-		$ifIndex = snmp_walk("$ip","$rocommunity",".1.3.6.1.2.1.15.3.1.1"); //bgp.bgpPeerTable.bgpPeerEntry.bgpPeerIdentifier
+		$ifIndex = snmp_walk($ip, $rocommunity, ".1.3.6.1.2.1.15.3.1.1"); //bgp.bgpPeerTable.bgpPeerEntry.bgpPeerIdentifier
 	    
 	    if (count($ifIndex) > 0) {
 		$ifLocal = snmp_walk($ip,$rocommunity,".1.3.6.1.2.1.15.3.1.5");
@@ -13,8 +17,6 @@
 		$ifRemoteAS = snmp_walk($ip,$rocommunity,".1.3.6.1.2.1.15.3.1.9");
 
 		for ($i=0; $i < count($ifIndex) ; $i++) if ($ifIndex[$i]) {
-		    list(, $ifRemote[$i]) = explode(":",$ifRemote[$i]);
-		    list(, $ifLocal[$i]) = explode(":",$ifLocal[$i]);
 		    list($ifOperStatus[$i]) = explode("(",$ifOperStatus[$i]);
 		
 		    switch ($ifOperStatus[$i]) {
