@@ -17,8 +17,8 @@
 	    if (is_array($services)) //verify if the array has something
         	foreach ( $services as $key=>$service ) {
 		    $service=trim(str_replace('"','',$service));
-		    $path=trim(str_replace('"','',$paths[$key]));
-		
+                    $path= preg_replace("/[^[:print:]]/","", trim(str_replace('"','', snmp_hex_to_string($paths[$key]))));
+		    		
 		    if (!isset($services_table[$service]))
             		$services_table[$service]=array(
 			    "interface"=>$service,
