@@ -1,10 +1,15 @@
 <?
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
     function discovery_tcp_ports($ip,$community, $host_id, $param) {
 
 	$nmap = get_config_option ("nmap_executable");
 	$temp = get_config_option ("engine_temp_path");
 
 	$ports = array();
+	list($ip) = explode(":",$ip); //remove :port from IP
 	$ip = gethostbyname ($ip);
 
 	if ((ip2long($ip)!==-1) && $host_id && (file_exists($nmap)===TRUE)) { 
