@@ -11,7 +11,7 @@ function graph_acct_packets ($data) {
 
     $opts_GRAPH = array( 		    
 	"AREA:packets#00CC00:'Accounting Packets (Probably Outbound)\\n'",
-    	"GPRINT:packets:MAX:'Max\:%6.0lf %s:Pps'",
+    	"GPRINT:packets:MAX:'Max\:%6.0lf %sPps'",
     	"GPRINT:packets:AVERAGE:'Average\:%6.0lf %sPps'",
     	"GPRINT:packets:LAST:'Last\:%6.0lf %sPps'"
 	);
