@@ -1,4 +1,8 @@
 <?
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
 
 // get Cisco IP Accounting Information 
 // URL : http://www.cisco.com/en/US/tech/tk648/tk362/technologies_tech_note09186a0080094aa2.shtml
@@ -13,11 +17,11 @@ function poller_cisco_accounting ($options) {
 	$total_bytes = 0;
 	$total_packets = 0;
 	
-	if (($options["host_ip"]) && ($options["rw_community"])) {
+	if (($options["host_ip"]) && (strlen($options["rw_community"]) > 3)) {
 	
 	    $checkpoint_id = snmp_get($options["host_ip"],$options["rw_community"],$checkpoint_oid);
 
-	    $get_data = @snmpset($options["host_ip"],$options["rw_community"],$checkpoint_oid,"i",$checkpoint_id); //mark checkpoint to get new data
+	    $get_data = snmp_set($options["host_ip"],$options["rw_community"],$checkpoint_oid,"i",$checkpoint_id); //mark checkpoint to get new data
 	    //var_dump($get_data);
 
 	    if ($get_data) { 
