@@ -29,8 +29,9 @@
 		$names = $pm3["names"];
 		
 		$total_ports = 0;
-		//$selected_ports = 0;
+		$selected_ports = 0;
 		
+		if (is_array($lines))
 		foreach ( $lines as $line ) {
 			if ( $line == $option and (strpos($names[$total_ports],"S") !== false) )
 				$selected_ports ++;
