@@ -6,7 +6,7 @@
 function poller_tcp_status ($options) {
     $time_tcp_normal = time_usec();
     
-    $host_ip = $options["host_ip"];
+    list($host_ip) = explode(":", $options["host_ip"]); //remove :port from host ip
     
     //Get the Port using only the first numeric characters.
     $i = 0;
