@@ -1,4 +1,8 @@
 <?
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
 
     function tool_if_alias_info() {
 	return array ("type"=>"text","param"=>array("size"=>40));
@@ -10,7 +14,7 @@
     }
 
     function tool_if_alias_set($int, $value) {
-	$result = @snmpset($int["host_ip"],$int["host_rwcommunity"],".1.3.6.1.2.1.31.1.1.1.18.".$int["interfacenumber"],"s",$value);
+	$result = snmp_set($int["host_ip"],$int["host_rwcommunity"],".1.3.6.1.2.1.31.1.1.1.18.".$int["interfacenumber"],"s",$value);
 	return $result;
     }
 
