@@ -259,7 +259,7 @@
 	"fields"=>array(
 	    "description"=>array(	"name"=>"Description",	"type"=>"textbox","size"=>30),
 	    "event"=>array(	"name"=>"Show Info",	"type"=>"textbox",	"size"=>30),
-	    "condition"=>array(	"name"=>"Condition",	"type"=>"textbox",	"size"=>100, "filter"=>false),
+	    "cond"=>array(	"name"=>"Condition",	"type"=>"textbox",	"size"=>100, "filter"=>false),
 	    "variable_show"=>array(	"name"=>"Show Expression",	"type"=>"textbox",	"size"=>100),
 	    "variable_show_info"=>array(	"name"=>"Show Unit",	"type"=>"textbox",	"size"=>30),
 	    NULL)
@@ -347,7 +347,7 @@
 	    "match_oid"=>array(		"name"=>"OID Match",	"type"=>"textbox","size"=>50),
 	    "command"=>array(		"name"=>"Receiver Command (file)",	"type"=>"textbox","size"=>30),
 	    "parameters"=>array(	"name"=>"Parameters",	"type"=>"textbox","size"=>100),
-	    "backend"=>array(		"name"=>"Backend",	"type"=>"select",	"func"=>"select_backends",	"size"=>30, "view"=>"backend_description"),
+	    "backend"=>array(		"name"=>"Backend",	"type"=>"select",	"func"=>"select_pollers_backend",	"size"=>30, "view"=>"backend_description"),
 	    "stop_if_matches"=>array(	"name"=>"Stop if Matches",		"type"=>"checkbox"),
 	    NULL)
 	);
