@@ -1,24 +1,26 @@
 <? 
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
     include("../auth.php"); 
-?>
-<STYLE>
-    td { font-size: 10pt; }
-</STYLE>
-<?
 
-    $map_id = 1; 
-    if ($map_profile = profile("MAP")) $map_id = $map_profile; 
+    $refresh=0;
+    adm_header("Event Filter");
+
+    $filtered = (profile("MAP") || profile("CUSTOMER"))?true:false;
+
+    if (empty($viewtype)) $viewtype="same";
 
     function filter_radio ($field,$data) {
 	if ($data==0) $data0=1;
 	if ($data==1) $data1=1;
 	if ($data==2) $data2=1;
 	
-	$radios .= radiobutton($field,$data1,1,0);
-	$radios .= radiobutton($field,$data2,2,0);
-	$radios .= radiobutton($field,$data0,0,0);
-	
-	adm_table_cell($radios,"center");
+	return 
+	     td(radiobutton($field,$data1,1,0), "radio").
+	     td(radiobutton($field,$data2,2,0), "radio").
+	     td(radiobutton($field,$data0,0,0), "radio");
     }
 
     function parse_radio_id($value) {
@@ -33,9 +35,6 @@
     }    
 
 
-    $refresh=0;
-    adm_header("Event Filter");
-
     if ($express_filter) {
 	$filtro_array = explode("^",$express_filter);
 	
@@ -115,104 +114,93 @@
 	}
     }
 
+    $filters = array(
+	"filter_date_start"=>array(
+	    "name"=>"Date Start",
+	    "values"=>select_date("date_start",$date_start,7,true,$date_start_hour,"")),
 
-    adm_table("100%","100%","center",1,2,0,"middle");
-    adm_form();
-    
-    std_table_row();
-    adm_table_header_cell("Yes Not Dont","center");
-    adm_table_header_cell("<u>Event Filter</u>","center",2);
-    adm_table_row_close();
+	"filter_date_stop"=>array(
+	    "name"=>"Date Stop",
+    	    "values"=>select_date("date_stop",$date_stop,7,true,$date_stop_hour,"")),
 
-    adm_table_row();
-    filter_radio("filter_date_start",$filter_date_start);
-    adm_table_header_cell("Date Start","right");
-    adm_table_cell(select_date("date_start",$date_start,7,true,$date_start_hour,""),"center");
-    adm_table_row_close();
+	"filter_zone"=>array(
+	    "name"=>"Zone", "hide_on_filter"=>true,
+	    "values"=>select_zones("zone_id",$zone_id)),
 
-    adm_table_row();
-    filter_radio("filter_date_stop",$filter_date_stop);
-    adm_table_header_cell("Date Stop","right");
-    adm_table_cell(select_date("date_stop",$date_stop,7,true,$date_stop_hour,""),"center");
-    adm_table_row_close();
+	"filter_host"=>array(
+	    "name"=>"Host", "hide_on_filter"=>true,
+	    "values"=>select_hosts("host_id",$host_id)),
+	
+	"filter_type"=>array(
+	    "name"=>"Event Types",
+    	    "values"=>select_event_types("type_id",$type_id,4,NULL,"",array(NULL,array("show_unknown"=>1)))),
+
+	"filter_severity"=>array(
+	    "name"=>"Severity",
+    	    "values"=>select_severity("severity_id",$severity_id,1)),
+
+	"filter_interfacename"=>array(
+	    "name"=>"Interface Name",
+    	    "values"=>textbox("interfacename",$interfacename,30)),
+
+	"filter_username"=>array(
+	    "name"=>"Username", "hide_on_filter"=>true,
+	    "values"=>textbox("username",$username,30)),
+
+	"filter_info"=>array(
+	    "name"=>"Extra Info ".br()."(also Tacacs+ Commands)", "hide_on_filter"=>true,
+	    "values"=>textbox("info",$info,30)),
+
+	"filter_ack"=>array(
+	    "name"=>"Acknowledged Event",
+    	    "values"=>hidden("ack",1)."&nbsp;")
+	
+	);
 
 
-    if ($map_id==1) {
-	adm_table_row();
-	filter_radio("filter_zone",$filter_zone);
-	adm_table_header_cell("Zone","right");
-	adm_table_cell(select_zones("zone_id",$zone_id),"center");
-	adm_table_row_close();
+    echo 
+	table("events_filter").
+	form().
+	table_row("Event Filter","title", 5, "", false).
+	tr_open("headers").
+	td("Field").
+	td("Yes").td("Not").td("Don't").
+	td("Values").
+	tag_close("tr").
+	tag("tbody","filters");
+	
+    foreach ($filters as $key=>$data) 
+	if (is_array($data) && (($filtered==false) || ($data["hide_on_filter"]!==true)))
+	echo 
+	    tr_open().
+	    td($data["name"], "field").
+	    filter_radio($key,$GLOBALS[$key]).
+	    td($data["values"], "value").
+	    tag_close("tr");
 
-	adm_table_row();
-	filter_radio("filter_host",$filter_host);
-	adm_table_header_cell("Host","right");
-	adm_table_cell(select_hosts("host_id",$host_id),"center");
-	adm_table_row_close();
-    }
-    
-    adm_table_row();
-    filter_radio("filter_type",$filter_type);
-    adm_table_header_cell("Event Types","right");
-    adm_table_cell(select_event_types("type_id",$type_id,4,NULL,"",Array(NULL,Array(show_unknown=>1))),"center");
-    adm_table_row_close();
 
-    adm_table_row();
-    filter_radio("filter_severity",$filter_severity);
-    adm_table_header_cell("Severity","right");
-    adm_table_cell(select_severity("severity_id",$severity_id,1),"center");
-    adm_table_row_close();
+    echo
+	tag_close("tbody").
+	table_row(    
+	    radiobutton("viewtype",(($viewtype=="same")?1:0),"same")." Same Window ".
+	    radiobutton("viewtype",(($viewtype=="same")?0:1),"new")." New Window "
+		,"view_type",5,"",false).
 
-    adm_table_row();
-    filter_radio("filter_interfacename",$filter_interfacename);
-    adm_table_header_cell("Interface Name","right");
-    adm_table_cell(textbox("interfacename",$interfacename,30),"center");
-    adm_table_row_close();
+	hidden("filter",1).
+	hidden("order_type",$order_type).
+	table_row(	
+	    adm_form_submit("Filter Events").
+	    "&nbsp;&nbsp;".
+	    control_button("Close","", "javascript: window.close();", "logoff.png")
+	    ,"submit",5,"",false).
+	
+	form_close().
+	table_close();
 
-    if ($map_id==1) {
-	adm_table_row();
-	filter_radio("filter_username",$filter_username);
-	adm_table_header_cell("Username","right");
-	adm_table_cell(textbox("username",$username,30),"center");
-	adm_table_row_close();
-
-	adm_table_row();
-	filter_radio("filter_info",$filter_info);
-	adm_table_header_cell("Extra Info <br><small>(also Tacacs+ Commands)</small>","right");
-	adm_table_cell(textbox("info",$info,30),"center");
-	adm_table_row_close();
-    }
-
-    adm_table_row();
-    filter_radio("filter_ack",$filter_ack);
-    adm_table_header_cell("Acknowledged Event","right");
-    adm_table_cell(hidden("ack",1)."&nbsp;");
-    adm_table_row_close();
-
-    
-    if ($viewtype=="same") $a = 1; else $b = 1;
-
-    std_table_row();
-    adm_table_cell("&nbsp;");
-    adm_table_cell(
-	radiobutton("viewtype",$a,"same")." Same Window ".
-	radiobutton("viewtype",$b,"new")." New Window "
-		,"center",2);
-    adm_table_row_close();
-
-    std_table_row();
-    echo hidden("filter",1);
-    echo hidden("order_type",$order_type);
-    adm_table_header_cell(adm_form_submit("Filter Events")."&nbsp;&nbsp;".
-	linktext("Close","javascript: window.close();"),"center",3);
-    adm_table_row_close();
-
-    adm_form_close();
-    
     adm_footer();
 
-
     if ($filter==1) {
+    
 	if ($filter_date_start>0) {
 	    $aux = date("Y-m-d H:i:s",strtotime($date_start)+$date_start_hour);
 	    $filter_url.="^date_start,$aux,".parse_radio_id($filter_date_start);
@@ -243,11 +231,13 @@
 
 	if (($filter_ack>0) && ($ack)) $filter_url.="^ack,$ack,".parse_radio_id($filter_ack);
 	
-	$url = "$jffnms_rel_path/events.php?span=25&refresh=0&express_filter=$filter_url&order_type=$order_type";
+	$url = $jffnms_rel_path."/events.php?span=25&refresh=0&express_filter=".$filter_url."&order_type=".$order_type;
 
-	echo "<SCRIPT> 
-		    if (document.forms[0].viewtype[0].checked) opener.location.href='$url'; 
-		    else window.open('$url'); 
-	</SCRIPT>\n";
+	echo script("
+	    if (document.forms[0].viewtype[0].checked) 
+		opener.location.href='$url'; 
+	    else 
+		window.open('$url'); 
+	");
     }
 ?>
