@@ -82,11 +82,23 @@
 	    case "logo_image":
 		$value = $GLOBALS["jffnms_rel_path"]."images/jffnms.png";
 		break;
+
+	    case "rrdtool_version":
+		if (file_exists($GLOBALS["rrdtool_executable"])) {
+		    exec($GLOBALS["rrdtool_executable"]." -v",$output);
+		    if (preg_match("/RRDtool (\d\.\d)\./i",$output[0],$parts))
+			$value = $parts[1];
+		}
+		break;
+
+    	    case "rrdtoo_font":
+        	$value = $GLOBALS["jffnms_real_path"] . "/engine/fonts/".basename($value);
+        	break;
 	}
     
 	//TEST Fix for Windows Path \\\\\ escaping problem
 	if ($value) $value = str_replace("\\","/",$value);
-    
+
 	return $value;  
     }
 
@@ -166,7 +178,7 @@
 		$auto_config_value = autoConfig($key, $value);
 		$result = call_user_func("check_".$type, $auto_config_value);
 		
-    	        if($result || ($key=="os_type")) {
+    	        if ($result || ($key=="os_type") || ($key=="rrdtool_version")) {
         	    $value = $auto_config_value;
         	    $state = 1;
     		} else 
