@@ -1,11 +1,15 @@
 <?
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
 	$no_db=0;
 	$auth_configuration_file = "config.php";
 	$auth_dirs = array("../conf","../../../conf","../../conf");
 
 	foreach ($auth_dirs as $auth_dir) {
-		if (file_exists("$auth_dir/$auth_configuration_file")) { 
-			include("$auth_dir/$auth_configuration_file"); 
+		if (file_exists($auth_dir."/".$auth_configuration_file)) { 
+			include($auth_dir."/".$auth_configuration_file); 
 			break;
 		} 
 	}
@@ -15,8 +19,9 @@
 	unset($authenticated);
 	
 	$client_pages = array( //pages the customer is allowed to see
-		"$jffnms_rel_path/view_performance.php",
-		"$jffnms_rel_path/admin/reports/state_report.php"
+    		$jffnms_rel_path."/admin/calendar.php",
+		$jffnms_rel_path."/view_performance.php",
+		$jffnms_rel_path."/admin/reports/state_report.php"
 		);
 
 	switch ($jffnms_auth_method) {
@@ -33,21 +38,27 @@
 
 	    case "login":
 		ini_set("session.save_handler", "files");
+		session_name("jffnms");
 		session_start();	
 
 		if (isset($_REQUEST["logout"]) && ($_REQUEST["logout"]==1)) {
 		    session_destroy();
 		    session_start();
 		}
+
+		if (($jffnms_version=="0.0.0") && ($_SERVER["REMOTE_ADDR"]=="128.30.52.13")) { //W3C Validator
+		    $_REQUEST["user"]="admin";
+		    $_REQUEST["pass"]="admin";
+		}
 		
 		if (!isset($_SESSION["authentification"]))
 		    $authentification = $jffnms->authenticate ($_REQUEST["user"],$_REQUEST["pass"],true,"from ".$_SERVER["REMOTE_ADDR"]);
-		
+
 		list ($authenticated, $auth_type, $auth_data) = $authentification;
 	
 		if(is_array($auth_data))
 		    extract($auth_data);
-		
+
 		if ($authenticated!=1) {
 		    if (!empty($_REQUEST["pass"]))
 			$error = "Invalid Username or Password";
@@ -67,14 +78,14 @@
 	    default:
 		die("Bad Authentication Method.");
 	}
-
+	
 	unset($authenticated);
             
 	if ($auth_type==2) { //its a customer
 		$GLOBALS["client_id"] = $auth_user_id; //overwrite the client_id to only show this customer data (the pages have to enforce it)
 
 		if (!in_array($_SERVER['SCRIPT_NAME'], $client_pages)) {
-			$url_limit = "$jffnms_rel_path/view_performance.php";
+			$url_limit = $jffnms_rel_path."/view_performance.php";
 			Header("Location: $url_limit");
 			die();
 		}
