@@ -1,45 +1,10 @@
 <? 
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
     include ("auth.php"); 
 
-    function page_header() {
-?>
-<style> 
-    a { text-decoration: none; }
-    img { border: 0px solid black; }
-    .ack { font-style: italic; font-size: 9pt; }
-    td { font-size: 10pt; }
-</style>
-
-<SCRIPT>
-
-    function go_filter(select) {
-	var id = select.options[select.selectedIndex].value;
-        location.href = location.href + '&express_filter=&filter_id='+id;
-	return true;
-    }
-
-    function check(field_aux) {
-	field=document.forms[0].elements[field_aux];
-        for (i = 0; i < field.length; i++) { 
-    	    if (field[i].checked==true)
-		field[i].checked = false; 
-	    else
-		field[i].checked = true; 
-	}
-	return true;
-    }
-
-    function popUp(URL) {
-	day = new Date();
-        id = day.getTime();
-	eval("window1 = window.open(URL, '" + id + "', 'toolbar=0,scrollbars=0,location=0,statusbar=0,menubar=0,resizable=0,width=600,height=450');");
-        if (!window1.opener) window1.opener = self;
-    }
-
-</SCRIPT>
-<?
-    } //function page_header
-
     function generate_filter() {
 	global $filter_id,$express_filter,$jffnms;
 
@@ -69,7 +34,7 @@
 		    if ($filtrorow=="type") $filter = "$filter and $oper (<events_table>.type = $filtrovalue)";
 		    if ($filtrorow=="username") $filter = "$filter and $oper (<events_table>.username LIKE '%$filtrovalue%')";
 		    if ($filtrorow=="severity") $filter = "$filter and $oper (types.severity = $filtrovalue)";
-		    if ($filtrorow=="interface") $filter = "$filter and $oper (<events_table>.interface LIKE '%$filtrovalue%')";
+		    if ($filtrorow=="interface") $filter = "$filter and $oper (<events_table>.interface LIKE '%$filtrovalue')";
 		    if ($filtrorow=="info") $filter = "$filter and $oper (<events_table>.info LIKE '%$filtrovalue%')";
 		    if ($filtrorow=="ack") $filter = "$filter and $oper (<events_table>.ack > 0)";
 
@@ -111,51 +76,94 @@
 	return array($have_filter, $filter, "options"=>$filter_options);
     } // function generate_filter
 
+    function add_journal ($journal_id, $checked_ids = array(), $subject= "", $comment = "", $ticket = false) {  
+	global $jffnms, $events_obj;
+	
+	$journal = $jffnms->get("journal");
+	
+	$event_ids = array();
+	
+	if (!is_array($checked_ids))
+	    $checked_ids=array();
+
+	foreach ($checked_ids as $aux) { 
+	    $aux2 = explode (",",$aux);
+	    foreach ($aux2 as $checked_id)
+		if (is_numeric($checked_id))
+		    $event_ids[]=$checked_id;
+	}
+
+	$event_ids = array_unique($event_ids);
+
+	if (!empty($comment)) { 
+	    $comment = trim ($comment);
+    	
+	    $now = date("Y-m-d H:i:s",time());
+
+    	    $timed_comment = "|".$now.",".$_SERVER["PHP_AUTH_USER"]."|\n".$comment."\n";
+	
+    	    if (($journal_id==1) && (!empty($subject))) { //new journal
+		$journal_data = array("date_start"=>$now, "subject"=>$subject);
+		$journal_id = $journal->add();
+
+	    } else 
+		if ($journal_id > 2) { //update journal
+		    unset($journal_data);
+		    $journal_data["date_stop"] = $now;
+		}
+	    
+	    if (is_array($journal_data) && ($journal_id > 1)) 
+		$journal->update ($journal_id,$journal_data,$timed_comment);
+	}
+
+	if (($journal_id > -1) && is_array($event_ids) && (count($event_ids) > 0)) {
+
+    	    foreach ($event_ids as $event_id) 
+		$events_obj->set_ack($event_id, $journal_id);
+	    
+	    if ($ticket && ($journal_id > 1)) 
+		$journal->create_ticket($journal_id); 
+	}
+	
+	return $journal_id;
+    }
+
     function show_journal($journal_id) {
-	global $jffnms,$REQUEST_URI_ORIGINAL,$color;
+	global $jffnms,$REQUEST_URI_ORIGINAL;
 
 	$journal = $jffnms->get("journal");
 	
 	if ($journal_id > 1) 
 	    $journal_active = current($journal->get_all($journal_id,1));
-	echo 
-	    hidden ("volver",$REQUEST_URI_ORIGINAL);
 	
-	adm_table("200","1","left",0,0,0,"top");
+	$output .= 
+	    table("journal").
+	    table_row("Journal","title", 4, "", false).
 
-	table_row("<b>Journal</b>","center",4);
+	    tr_open("selector").
+	    td (select_journal("journal_id",$journal_id,array(1=>"New Journal"))).
+	    td (adm_form_submit("View","view_button")).
+	    td (adm_form_submit("Acknowledge","journal_button")).
+
+	    td (((!$journal_active["ticket"])
+		?adm_form_submit("Send to Ticket","ticket_button")
+		:linktext("Ticket ".$journal_active["ticket"],$journal->view_ticket_url($journal_id),"map"))).
+
+	    tag_close("tr").
 	
-	std_table_row($color);
-	adm_table_cell(select_journal("journal_id",$journal_id,array(1=>"New Journal")),"right",1);
-	adm_table_cell(adm_form_submit("View","view_button"),"center",1);
-	adm_table_cell(adm_form_submit("Acknowledge","journal_button"),"center",1);
+	    tr_open().
+	    td("Subject: ".textbox("subject",$journal_active["subject"],30),"","",4).
+	    tag_close("tr").
 
-	if (!$journal_active["ticket"]) 
-	    adm_table_cell(adm_form_submit("Send to Ticket","ticket_button"),"center",1);
-	else 
-	    adm_table_cell(linktext("Ticket ".$journal_active["ticket"],$journal->view_ticket_url($journal_id),"map"),"center",1);
-
-	adm_table_row_close();
-
-	std_table_row($color);
-	adm_table_cell("<b>Subject:</b>","right",1);
-	adm_table_cell(textbox("subject",$journal_active["subject"],30,50),"left",3);
-	adm_table_row_close();
-
-	std_table_row($color);
-
-	if ($journal_id > 1) { 
-	    adm_table_cell("<PRE>".$journal_active["comment"]."</PRE>","left",2);	
-	    adm_table_cell(memobox("comment",6,30,""),"center",2);
-	} else 
-	    adm_table_cell(memobox("comment",3,40,""),"center",4);
-
-	adm_table_row_close();
-	
-        adm_table_close();
-
-    } //function show_journal
+	    tr_open ().
+	    (($journal_id > 1)
+		?td(nl2br($journal_active["comment"]), "", "", 2, true):"").
+	    td(memobox("comment",7,40,""),"text","",($journal_id > 1)?2:4).
+	    tag_close("tr").
+	    table_close();
 
+	return $output;
+    } 
 
     function event_table_header ($refresh, $express_filter, $filter_id, $init, $span, $sound) {
 	global $REQUEST_URI, $order_type, $view_type, $jffnms_rel_path, $view_all;
@@ -173,77 +181,85 @@
 	switch ($view_type) {
 	    case "html":
 		$output .= 
-		"\t<tr bgcolor='#AAABA1' height='15'>\n".
-		"\t\t<td nowrap align='center' width='5%'>\n".
-		"\t\t\t<b>Date</b> <a href='$REQUEST_URI&order_type=$order_change'><img src='images/$order_image'></a>\n".
-		"\t\t\t<font color='white'><b><small>".date("H:i:s",time())."</small></b></font></td>\n".
-		"\t\t<td nowrap align=center width='2%'><b>Ack</b></td>\n".
-		"\t\t<td nowrap align=center width='8%'><b>Type</b></td>\n".
-		"\t\t<td nowrap align=center width='10%' colspan=2><b>Host & Zone</b></td>\n".
-		"\t\t<td align=center nowrap>\n".
-		"\t\t\t<table width='100%' border=0 cellspacing=0 cellpadding=0>\n".
-		"\t\t\t\t<tr>\n".
-		"\t\t\t\t\t<td align=left nowrap valign=center>\n".
-		"\t\t\t\t\t\t<a href='$REQUEST_URI&init=0&expand=0&refresh='><img src='images/a-top.png'></a>&nbsp;".
+		    tr_open ("","header").
+		    td ("Date". linktext(image($order_image),$REQUEST_URI."&order_type=".$order_change).
+			html("span",date("H:i:s",time()),"","hour"),"date").
+		
+		    td ("Ack", "ack").
+		    td ("Type", "type").
+		    td ("Host & Zone", "host", "", 2).
+		
+		    tag ("td").
+		    table ("","buttons").
+		    tr_open ().
+		    td (linktext(image("a-top.png"), $REQUEST_URI."&init=0&refresh=")).
 
-		(($init>0)?
-		    "\t\t\t\t\t\t<a href='$REQUEST_URI&init=".($init-$span)."&expand=0&refresh=0'><img src='images/a-left.png' alt='Previous Page'></a>&nbsp;\n":
-		    "\t\t\t\t\t\t&nbsp;&nbsp;&nbsp;\n").
+		    td (($init > 0)
+			    ?linktext(image("a-left.png"), $REQUEST_URI."&init=".($init-$span)."&refresh=0")
+			    :"").
 
-		"\t\t\t\t\t\t<a href='$REQUEST_URI&init=". ($init+$span)."&expand=0&refresh=0'><img src='images/a-right.png' alt='Next Page'></a>&nbsp;\n".
+		    td (linktext(image("a-right.png"), $REQUEST_URI."&init=". ($init+$span)."&refresh=0")).
+		    
+		    td ((empty($refresh)
+			    ?linktext(image("refresh.png"), $REQUEST_URI."&refresh=")
+			    :image("refresh2.png", NULL, NULL,"Refresh","","",
+				"if (self.no_refresh!=1) {
+				    self.no_refresh = 1; 
+				    this.src = \"images/refresh.png\"; 
+				} else 
+				    document.location = \"".htmlspecialchars($REQUEST_URI)."\";
+				"))).
+			
+		    td (linktext(image("plus.png"), $REQUEST_URI."&span=".($span*2))).
+		    td (linktext(image("minus.png"), $REQUEST_URI."&span=".($span/2))).
 
-		((empty($refresh))?
-		    "\t\t\t\t\t\t<a href='$REQUEST_URI&refresh='><img src='images/refresh.png' alt='Refresh'></a>\n":
-		    "\t\t\t\t\t\t<img OnClick=\"javascript: if (self.no_refresh!=1) { self.no_refresh = 1; this.src='images/refresh.png'; } else document.location = '$REQUEST_URI';\" src='images/refresh2.png' alt='Stop Refresh'>\n").
-		"\t\t\t\t\t\t ( \n".
-		"\t\t\t\t\t\t<a href='$REQUEST_URI&span=".($span*2)."'><img src='images/plus.png' alt='More Events'></a>\n".
-		"\t\t\t\t\t\t<a href='$REQUEST_URI&span=".($span/2)."'><img src='images/minus.png' alt='Less Events'></a>\n".
+		    td ((($view_all==0)
+			?linktext(image("all.png"), $REQUEST_URI."&view_all=1&refresh=0")
+			:linktext("- ".image("all.png"), $REQUEST_URI."&view_all=0"))).
 
-		(($view_all==0)?
-		    "\t\t\t\t\t\t<a href='$REQUEST_URI&view_all=1&refresh=0'><img src='images/all.png' alt='All Events'></a>\n":
-		    "\t\t\t\t\t\t<a href='$REQUEST_URI&view_all=0'> -<img src='images/all.png' alt='Not All Events'></a>\n").
-		"\t\t\t\t\t\t ) \n".
+		    td ((($sound==1)
+			?linktext(image("sound.png"), $REQUEST_URI."&sound=0")
+			:linktext(image("nosound.png"), $REQUEST_URI."&sound=1"))).
 
-		(($sound==1)?
-		    "\t\t\t\t\t\t<a href='$REQUEST_URI&sound=0'><img src='images/sound.png' width=14 height=14 alt='Disable Sound'></a>\n":
-		    "\t\t\t\t\t\t<a href='$REQUEST_URI&sound=1'><img src='images/nosound.png' width=14 height=14 alt='Enable Sound'></a>\n").
-		"\t\t\t\t\t</td>\n".
-		"\t\t\t\t\t<td align=center><b>Event</b></td>\n".
-		"\t\t\t\t\t<td align=right>\n".
-		"\t\t\t\t\t<a href='$REQUEST_URI&view_type=csv&view_all=1' target='_new'><img src='images/csv.png' width=14 height=14 alt='Export to Excel/CSV'></a>\n".
-		"\t\t\t\t\t<a href=\"javascript: popUp('$jffnms_rel_path/admin/event_filter.php?order_type=$order_type&express_filter=$express_filter');\"><img src='images/filter.png' width=14 height=14 alt='Filter'></a>\n".
-		"\t\t\t\t\t".select_custom("filter_list",$filter["options"],(isset($filter["options"][0])?"":$filter_id),"go_filter(this);").
-		"\t\t\t\t</td>\n".
-		"\t\t\t</tr>\n".
-		"\t\t</table>\n".
-		"\t</td>\n".
-		"</tr>\n";
+		    td ("Event", "detail").
+	
+		    td (
+			linktext(image("csv.png"), $REQUEST_URI."&view_type=csv&view_all=1", "_new").
+			linktext(image("filter4.png"), 
+			    "javascript: popUp('".$jffnms_rel_path."/admin/event_filter.php?order_type=".
+			    $order_type."&express_filter=".$express_filter."');").
+			select_custom("filter_list",$filter["options"],(isset($filter["options"][0])?"":$filter_id),"go_filter(this);"),
+			"filters").
+	
+		    tag_close("tr").
+		    table_close().
+		    tag_close("td").
+		    tag_close("tr");
 	
 		unset ($filter["options"]);
 	    break;
 	
 	    case "csv":
-		$output .= "<PRE>\n";
+		$output = tag("pre");
 	        $output .= "# Save this file as .txt and then open it on your Spreadsheet, import it as CSV (Comma Separated Values)\n";
 		$output .= "Day,Hour,Host,Zone,Username,Interface,Event Type,State,Info,Severity\n";
 	    break;
 	
+	    case "rss":
 	    case "rdf": 
-    		Header ("Content-Type: text/xml");
+    		header ("Content-Type: text/xml");
 		$output .=
-		    "<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>\n".
-		    "<rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns=\"http://my.netscape.com/rdf/simple/0.9/\">\n".
-		    "<channel>\n".
-		    "\t<title>JFFNMS</title>\n".
-		    "\t<link>http://".$_SERVER["HTTP_HOST"]."$jffnms_rel_path</link>\n".
-		        "\t<description>JFFNMS Events</description>\n".
-		    "</channel>\n";
+		    "<?xml version='1.0' encoding='ISO-8859-1' ?>\n".
+		    tag ("rss", "", "", "version='2.0'").
+		    tag ("channel").
+			html("title", "JFFNMS", "", "", "", false, true).
+		        html("link", current_host().$jffnms_rel_path, "", "", "", false, true).
+			html("description", "JFFNMS Events", "", "", "", false, true).
+		    html("ttl",$refresh, "", "", "", false, true);
 		break;
 	}
 
-	echo $output;
-
-	return $filter;
+	return array($output, $filter);
     } //function event_table_header
 
 
@@ -288,13 +304,20 @@
 	return $result; //return event
     }
 
-
     // ------ EVENTS CORE
 
     $REQUEST_URI_ORIGINAL = $REQUEST_URI;	    //guarda el URI para algunos casos
 
     $events_obj = $jffnms->get("events");
 
+    clean_url (array(), 
+	array("journal_id","journal_button", "ticket_button","comment","subject", "checkedid","filter_list"));
+
+    if (isset($journal_button))
+	$journal_id = add_journal($journal_id, $checkedid, $subject, $comment, (isset($ticket_button)?true:false));
+
+    //FIXME view Journals
+
     //for scrolling
     if ($init=="") $init = 0;
     if ($span=="") $span = 15;
@@ -302,10 +325,7 @@
     
     $show_all = 0;
 
-    if ($sound=="") 
-	$sound = profile("EVENTS_SOUND");
-    else 
-	profile_modify_value($auth_user_id,"EVENTS_SOUND",$sound);
+    $sound = profile("EVENTS_SOUND", $sound);
 
     if ($map_profile = profile("MAP")) $map_id = $map_profile; //fixed map
 
@@ -322,22 +342,54 @@
     if (!$view_type) $view_type = "html";
     if (!$view_mode) $view_mode = "normal";
 
+    list($header_html,$filter_aux) = event_table_header ($refresh, $express_filter, $filter_id, $init, $span, $sound); 
+
     if ($view_type=="html") { 
 	//Disable Refresh in adm_header()
 	$refresh_aux = $refresh;
 	$refresh="";
-	adm_header ("$title Event Viewer");
+
+	adm_header ($title." Event Viewer");
+
 	$refresh=$refresh_aux;
 
-        page_header(); 
+ 	list($have_filter,$filter) = $filter_aux;
 
-	adm_table("100%","1","center",0,0,1,""); // main table
+	echo script (
+"    function go_filter(select) {
+	var id = select.options[select.selectedIndex].value;
+        location.href = location.href + '&express_filter=&filter_id='+id;
+	return true;
+    }
 
-	echo "<form name=events action='journal.php'>\n";
+    function check(field_aux) {
+	fields=document.forms[0].elements;
+
+        for (i = 0; i < fields.length; i++) 
+	    if (fields[i].name==field_aux) { 
+    		if (fields[i].checked==true)
+		    fields[i].checked = false; 
+		else
+		    fields[i].checked = true; 
+	    }
+	return true;
+    }
+
+    function popUp(URL) {
+	day = new Date();
+        id = day.getTime();
+	eval(\"window1 = window.open(URL, '\" + id + \"', 'toolbar=0,scrollbars=0,location=0,statusbar=0,menubar=0,resizable=0,width=600,height=380');\");
+        if (!window1.opener) window1.opener = self;
+    }").
+    
+	form().
+	table("events"); // main table
     }
     
-    if ($view_mode=="normal")
-	list($have_filter,$filter) = event_table_header ($refresh, $express_filter, $filter_id, $init, $span, $sound); 
+    echo $header_html;
+    
+    if ($view_type=="html")
+	echo tag("tbody", "body");
     
     //list events
     $span_extended = $span * 2; //expanded for summary
@@ -383,11 +435,9 @@
 		    $first=false; 
 		}
 	
-		if (($expand == $event["id"]) && ($event["ack"] > 1)) $journal_id = $event["ack"]; //save journal id 
+		//if (($expand == $event["id"]) && ($event["ack"] > 1)) $journal_id = $event["ack"]; //save journal id 
 	
-		table_shift_color($color);
-
-		show_event ($event, $color, $expand, $map_id, $filter_id);
+		show_event ($event, $color, $map_id, $filter_id);
 
 		if ($order_type=="desc") 
 		    $event_pos++; 
@@ -398,55 +448,56 @@
 	    }
 
 	if ($view_type=="html") {
-	    table_shift_color($color);
-
-	    echo "<!-- Events End -->\n".
-		"<tr align='center' bgcolor='$color'>\n".
-	    	"\t<td>General</td>\n".
-		"\t<td align='center'><input type=checkbox onClick=\"this.value=check('checkedid[]');\">All</td>\n".
-		"\t<td colspan=4>\n";
-
-		show_journal($journal_id);
-		
 	    echo 
-		"\t</td>\n".
-		"</tr>\n";
+		tr_open("general").
+	    	td ("General").
+		td (tag("input","","","type='checkbox' onClick=\"this.value=check('checkedid[]');\"",false)."All").
+		td (show_journal($journal_id),"","",4, true).
+		tag_close("tr");
 
-	    if ($view_mode=="normal")
-		event_table_header($refresh, $express_filter, $filter_id, $init, $span, $sound);  
-	    
-	    adm_form_close(); //journal form
-	    adm_table_close(); //main table
-
-	    if ($view_mode=="normal") { //to allow scroll at the bottom
-		adm_table();
-	        table_row("&nbsp;");
-		adm_table_close();
-	    }
+	    echo 
+		tag_close("tbody").
+		(($view_mode=="normal")
+		    ?(current(event_table_header($refresh, $express_filter, $filter_id, $init, $span, $sound))):"").
+		table_close().
+		form_close();
 	} //html
     
-    } else //if we didn't find any events
+    } else { //if we didn't find any events
+	$no_events_found = "No Events Found";
+	
 	switch ($view_type) {
 	    case "html":	
-    		table_shift_color($color);
-	        std_table_row($color);
-	        adm_table_cell("<b>No Events Found</b>","center",6);
+	        table_row($no_events_found,"no_events_found",6);
 	    break;
 	
-	    case "cvs":
+	    case "csv":
+		echo $no_events_found."\n";
+	    break;
+	    
+	    case "rss":
 	    case "rdf":
 	    default:
-		echo "No Events Found\n";
+		echo
+		    html("item", 
+			html("title", $no_events_found, "", "", "", false, true).
+			html("pubDate", date("Y-m-d H:i:s"), "", "", "",false, true).
+			html("link", 
+			    htmlspecialchars(current_host().$REQUEST_URI."&view_type=html"), "", "", "",false, true)
+			);
 	    break;
 	}
-    
-    // Sound Execution
-    if (($events_actual > $events_last) && ($events_last) && ($sound==1)) 
-	echo play_sound($events_sound);
+    }
 
     // Page End
     switch ($view_type) {
 	case "html":
+
+	    // Sound Execution
+    	    if ($sound==1)
+    		if (($events_actual > $events_last) && ($events_last))
+		    echo play_sound($events_sound);
+
 	    // Recode URL for JS refresh
     	    if ($_GET) 
 		$url = $_GET; //suport for PHP 4.1.0 and older
@@ -456,16 +507,20 @@
 	    $url["events_last"] = $events_actual;
 
 	    foreach ($url as $key => $value) 
-		$url_aux .= "&$key=$value";
+		$url_aux .= "&$key=".$value;
 
-	    $url = "$SCRIPT_NAME?$url_aux";
-    
-	    echo "\n".javascript_refresh("if (self.no_refresh!=1) location.href=\"$url\";",$refresh); 
+	    $url = $SCRIPT_NAME."?".$url_aux;
+
+	    echo javascript_refresh("if (self.no_refresh!=1) location.href=\"$url\";",$refresh);
+	    
 	    adm_footer();
 	break;
 	    
+	case "rss":
 	case "rdf": 
-	    echo "\n</rdf:RDF>\n";
+	    echo
+		tag_close("channel").
+		tag_close("rss");
 	break;
     }
 ?>
