@@ -28,8 +28,8 @@
     if ($view_stats==1) {
     
 	$alarms = ($map_id==1) 
-	    ?$jffnms->interfaces->status(NULL,array("in_maps"=>1, "client"=>$client_id)) //all interfaces in rootmap
-	    :$jffnms->interfaces->status(NULL,array("map"=>$map_id, "client"=>$client_id)); //all interfaces in map
+	    ?$jffnms->interfaces->status(NULL,array("in_maps"=>1,   "client"=>$client_id, "only_visible"=>true)) //all interfaces in rootmap
+	    :$jffnms->interfaces->status(NULL,array("map"=>$map_id, "client"=>$client_id, "only_visible"=>true)); //all interfaces in map
 	
 	foreach ($alarms as $key=>$value) 
     	    if ($key!="total") $alarms_text .= "<b>".$key.":</b> ".$value["qty"]."<br>";
