@@ -1,4 +1,8 @@
 <?
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
     if ($map_id > 1) $only_rootmap = 0;
     
     $interfaces_filter = array("map"=>$map_id,"host"=>$host_id,"in_maps"=>$only_rootmap,"map_order"=>1,
@@ -40,7 +44,7 @@
 	    "type"=>$item["type_description"],
 	    "type_id"=>$item["type"],
 	    //if the host is in show, use the interface show field, if its not, use the host field 
-	    "show_rootmap"=>(($item["host_show"]==1)?$item["show_rootmap"]:$item["host_show"]),
+	    "show_rootmap"=>($item["zone_show"]==1?(($item["host_show"]==1)?$item["show_rootmap"]:$item["host_show"]):$item["zone_show"]),
 	    "check_status"=>$item["check_status"],
 
 	    //alarm
