@@ -6,7 +6,7 @@
 	unset ($aux_description_formated);
 	
 	foreach ($item["description"] as $aux_desc=>$aux_value)
-	    $aux_description_formated .= "<br><b>$aux_desc:</b> $aux_value";
+	    $aux_description_formated .= "<br><b>$aux_desc:</b> ".htmlentities($aux_value);
 	
 	$aux_description = join(" ",$item["description"]); //to be used elsewere
 
