@@ -1,5 +1,19 @@
-<SCRIPT>
+<?
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
 
+    unset($refresh);
+    adm_header("Alarm Map", $map_color);
+
+    // Popup Delays
+    $base_delay = 1000;
+    $show_delay = $base_delay*1;
+    $hide_delay = $show_delay*4; //take 4 times more time to hide than to show
+
+    echo 
+	script("
 var shown_objects = new Array();
 var lastzIndex = 1;
 
@@ -13,7 +27,7 @@ function show_info(o,text) {
 	    if (shown_objects[i]['state']==0) 	//if it was not shown yet
 		shown_objects[i] = null;	//just delete it, to avoid it to be shown
 	    else
-		window.setTimeout ("real_hide_info('"+i+"');",5000); //hide it normally
+		window.setTimeout (\"real_hide_info('\"+i+\"');\",".$hide_delay."); //hide it normally
 	}
 	
     if (!shown_objects[oid]) { //if not's already created
@@ -21,7 +35,7 @@ function show_info(o,text) {
     	shown_objects[oid]['obj'] = o;
     	shown_objects[oid]['state'] = 0;
 
-    	window.setTimeout ("real_show_info('"+text+"','"+oid+"');",2000); //delay real show
+    	window.setTimeout (\"real_show_info('\"+text+\"','\"+oid+\"');\",".$show_delay."); //delay real show
     }
 }
 
@@ -46,10 +60,10 @@ function real_show_info(text,oid) {
     shown_objects[oid]['old_border'] = o.style.borderStyle;
 
     //save current position values
-    x = parseInt(o.style.left.replace("px",""));
-    y = parseInt(o.style.top.replace("px",""));
-    w = parseInt(o.style.width.replace("px",""));
-    h = parseInt(o.style.height.replace("px",""));
+    x = parseInt(o.style.left.replace('px',''));
+    y = parseInt(o.style.top.replace('px',''));
+    w = parseInt(o.style.width.replace('px',''));
+    h = parseInt(o.style.height.replace('px',''));
 
     o.style.width = 'auto' ;
     o.style.height = 'auto' ;
@@ -57,7 +71,7 @@ function real_show_info(text,oid) {
     o.style.zIndex = lastzIndex++;
 
     o.innerHTML = text;
-    o.style.fontSize = '<? echo round($charsize*1.6); ?>px';
+    o.style.fontSize = '".round($charsize*1.6)."px';
     o.style.lineHeight = o.style.fontSize;
 
     o.style.borderStyle = 'solid';
@@ -86,8 +100,6 @@ function real_show_info(text,oid) {
     new_y -= win_t;
     new_x -= win_l;
     
-    //alert ("t: "+win_t+" l: "+win_l+" w: "+win_w+" h: "+win_h+"\n t: "+new_y+" l: "+new_x+" w: "+new_w+" h: "+new_h);    
-    
     if ((new_x + new_w) >= win_w)
 	o.style.left = win_w - new_w - dif + win_l;
 
@@ -100,15 +112,15 @@ function real_show_info(text,oid) {
     if (new_y <= dif) 
 	o.style.top  = win_t + dif;
 
-    x = parseInt(o.style.left.replace("px",""));
-    y = parseInt(o.style.top.replace("px",""));
+    x = parseInt(o.style.left.replace('px',''));
+    y = parseInt(o.style.top.replace('px',''));
 
     toolbox_show(oid,x,new_w,y+new_h);
     return 0;
 }
 
 function hide_info(o) {
-    window.setTimeout ("real_hide_info('"+o.id+"');",6000); //delay real hide
+    window.setTimeout (\"real_hide_info('\"+o.id+\"');\",".$hide_delay."); //delay real hide
 }
 
 function real_hide_info(oid) {
@@ -142,36 +154,38 @@ function real_hide_info(oid) {
 }
 
 function ir_url(url,url2){
-    if (url!="") {
-	if (top.trabajo.events) top.trabajo.events.location.href = url; //if events frame exists use it
+    if (url!='') {
+	if (top.work && top.work.events) 
+	    top.work.events.location.href = url; //if events frame exists use it
 	else 
-	    if (url2=="") 
+	    if (url2=='') 
 		url2=url; //if it doesnt and this is the only url take it to the main frame
 //	    else
 //		window.open(url); //if the events frame doesn't exists, but we have to show 2 urls, show this one in a new window
     }
-    if (url2!="") {
-	if (!top.trabajo.map) 
-	    if (!top.trabajo) window.open(url2); //esto hace que si no esta la frame salga una window
-	    else top.trabajo.location.href = url2; //y esto que si no esta map salga en trabajo
-	else top.trabajo.map.location.href = url2;
+    
+    if (url2!='') {
+	if (top.work && top.work.map)
+	    top.work.map.location.href = url2;
+	else
+	    if (top.work)
+		top.work.location.href = url2; //y esto que si no esta map salga en work
+	    else
+		window.open(url2); //esto hace que si no esta la frame salga una window
     }
-}
+}").
 
-</SCRIPT>
-
-<script src="views/toolbox.js"></script>
-
-<style type="text/css">
+    html ("script", "", "", "", "src='views/toolbox.js'").
 
+    html ("style","
 .interface {
     position:absolute; 
     border-width: 1px; 
     border-color: black;
     border-style: solid;
-    font-size: <? echo $charsize; ?>px; 
+    font-size: ".$charsize."px; 
+    line-height: ".$charsize."px; 
     font-family: sans-serif,monospace,arial; 
-    line-height: <? echo $charsize; ?>px; 
     letter-spacing: 0px; 
     white-space: nowrap;
     margin: 0px 0px 0px 0px; 
@@ -182,17 +196,12 @@ function ir_url(url,url2){
     word-wrap: none;
     text-align: center;
     cursor: pointer;
-}
-</style>
-<? 
-    unset($refresh);
+}","","","type='text/css'").
 
-    adm_header("Alarm Map","$map_color");
+    script("
+    //FIX IE Things
+    if (document.all) {
+	document.styleSheets[0].rules[0].style.paddingTop = '0px';
+        document.styleSheets[0].rules[0].style.cursor = 'hand';
+    }");
 ?>
-<script>
-//FIX IE Things
-if (document.all) {
-    document.styleSheets[0].rules[0].style.paddingTop = '0px';
-    document.styleSheets[0].rules[0].style.cursor = 'hand';
-}
-</script>
