@@ -1,6 +1,10 @@
 <?
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
     function get_db_list($tables,$ids = NULL,$fields=NULL, $where= NULL, $order= NULL, $index = "", $groups = NULL, $limit_init = NULL, $limit_span = NULL) {
-	
+
 	if (!$tables) return FALSE;
 	
 	if (!$fields) $fields = "*";
@@ -387,10 +391,13 @@ function db_copy_table ($from,$to,$cant = NULL) {
 			$query="OPTIMIZE TABLE $table";
 			$result2 = db_query($query) or die("optimize($table) Error :".mysql_error());
 			
+			$query="ALTER TABLE ".$table." AUTO_INCREMENT = 1;";
+			$result3 = db_query($query) or die("auto_increment($table) Error :".mysql_error());
+			
 			$result1 = db_fetch_array($result1);
 			$result2 = db_fetch_array($result2);
 			
-			$result = $result1["Msg_text"]."/".$result2["Msg_text"];
+			$result = $result1["Msg_text"]."/".$result2["Msg_text"]."/".$result3;
 			
 			break;
 
