@@ -4,6 +4,24 @@
  * This program is licensed under the GNU GPL, full terms in the LICENSE file
  */
 
+    function interfaces_get_by_field_value($host_id, $interface_type, $field_name, $field_value) {
+    
+	$query=
+	    "SELECT i.id as interface_id,i.interface as interface ".
+	    "FROM interfaces_values iv, interface_types_fields itf, interfaces i ".
+	    "WHERE iv.field=itf.id AND iv.interface=i.id ".
+		"AND itf.name='".$field_name."' AND itf.itype=".$interface_type." AND i.host=".$host_id." AND value='".$field_value."'";
+    
+	$result=db_query($query) or die("query failed ($query) - interfaces_get_id_by_field_value: ".db_error());
+	
+	if(0 < db_num_rows($result)) {
+	    $row=db_fetch_array($result);
+	    return $row;	    	    	    
+	} else {
+	    return array("interface"=>NULL,"interface_id"=>-1);
+	}	
+    }
+
     function interfaces_filter($filters = NULL) {
 	$from = array();
 	$where = array();
@@ -91,6 +109,14 @@
 					$fields["host_rwcommunity"]	="hosts.rwcommunity";
 					$fields["host_satellite"]	="hosts.satellite";
 					break;
+					
+		    case "only_visible":
+					if ($filter_value) {
+					    $where[] = array("interfaces.show_rootmap", "=", "1");
+					    $where[] = array("hosts.show_host", "=", "1");
+					    $where[] = array("zones.show_zone", "=", "1");
+					}
+					break;
 		}
 		
 	    $where[]=array("interfaces.id",">",$interface_id_filter); //filter interface id 
@@ -128,12 +154,12 @@
 	else
 	    $alarm_join_type = "LEFT OUTER"; //show null if not found
 
-	$from   = "FROM hosts".(($aux_from!="")?", $aux_from":"").", interfaces";
+	$from   = "FROM zones, hosts".(($aux_from!="")?", $aux_from":"").", interfaces";
 	$joins 	= 	"$alarm_join_type JOIN alarms on (alarms.interface = interfaces.id and interfaces.check_status = 1 and $alarms_filter)\n".
 			"LEFT OUTER JOIN types on (types.id = alarms.type)\n".
 			"LEFT OUTER JOIN severity on (types.severity = severity.id)\n". 
 			"LEFT OUTER JOIN alarm_states on (alarms.active = alarm_states.id and $alarm_state_filter)";
-	$where	= "WHERE interfaces.id > 1 and interfaces.host = hosts.id"; 
+	$where	= "WHERE interfaces.id > 1 and interfaces.host = hosts.id and hosts.zone = zones.id"; 
 	
 	if (is_array($where_special))
 	    foreach ($where_special as $aux)
