@@ -98,7 +98,7 @@
 	    array($p["timeout"]*1000000,$p["retries"])); 
 	
 	$result = @call_user_func_array("snmp2_".((($p["action"]=="walk") && ($p["include_oid"]))?"real_":"").$p["action"], $params);
-       
+
         if (is_string($result) &&
 	    (preg_match("/No Such (Object|Instance)/i", $result) || preg_match("/No more variables left/i", $result)))
 	    $result = false;
@@ -153,11 +153,17 @@
 		:array()),
 	    array($p["timeout"]*1000000,$p["retries"])); 
 
-	return @call_user_func_array(
+	$result = @call_user_func_array(
 	    "snmp3_".
 	    ((($p["action"]=="walk") && ($p["include_oid"]))?"real_":"").
 	    $p["action"], 
 	    $params);
+
+	if (is_string($result) &&
+	    (preg_match("/No Such (Object|Instance)/i", $result) || preg_match("/No more variables left/i", $result)))
+	    $result = false;
+
+	return $result;
     }
 
     // Aux SNMP Functions
