@@ -36,7 +36,7 @@
         	if (is_array($opts))
             	    foreach ($opts as $key=>$data) { //windows
                 	$opts[$key] = str_replace("'","\"",$opts[$key]);
-                        $opts[$key] = str_replace(":/","\:/",$opts[$key]);
+                        if ($key!="font") $opts[$key] = str_replace(":/","\:/",$opts[$key]); //font does not need this
                     }
 
             if (is_array($opts)) $aux = join($opts," ");
@@ -50,7 +50,7 @@
                 $command = $rrdtool_executable." ".$method." '".$file."' ".$aux;
 
 		//Check if we can use the new Piped/Managed RRDTool method
-		if (!isset($GLOBALS["rrdtool_not_use_pipe"]) && function_exists("proc_open")) 
+		if (!isset($GLOBALS["rrdtool_not_use_pipe"]) && function_exists("proc_open") && (strlen($command) < 10000))
 		    $use_pipe = true;
 	    }
 	    
@@ -217,19 +217,36 @@
 	    } else 
 		logger ("ERROR Loading file $function_file.<br>\n");
 
+	
+	    // Specific changes for RRDTool 1.2.x
+	
+	    if (get_config_option("rrdtool_version")=="1.2") { 
+		$opts_header["font"] = "--font=DEFAULT:7:".get_config_option("rrdtool_font"); //Set the Font for RRDTool 1.2.x
+
+		if (is_array($graph_definition))
+		    foreach ($graph_definition as $k=>$v) 
+			if (strpos($v, "COMMENT")!==false) //RRDTool 1.2.x needs the : (colons) inside COMMENTs to be escaped with \ as \:
+			    $graph_definition[$k] = substr($v, 0, strpos($v, ":")+1). str_replace(":","\:",substr($v, strpos($v, ":")+1));
+	    }	
 	    
 	    $opts = @array_merge(
 			$opts_header,
 			(($aux=="MINI")
-			    ?array("--no-legend","--alt-y-mrtg")
+			    ?array("--no-legend", ((get_config_option("rrdtool_version")=="1.0")?"--alt-y-mrtg":"")) //RRDTool 1.2.x does not have the --alt-y-mrtg option
 			    :$graph_header),
 			$graph_definition);
+
+	    // Clear out empty opts array items, because it causes problems with some RRDTools
+	    if (is_array($opts))
+	    foreach ($opts as $k=>$v)
+		if (empty($v))
+		    unset ($opts[$k]);
 	    
 	    $graph_filename = get_config_option ("engine_temp_path")."/".uniqid("").".dat"; //generate random graph filename
 	    
 	    $ret = rrdtool_graph($graph_filename, $opts);
 	    
-	    if (($aux!="MINI") && ($ret!=FALSE)) rrdtool_add_legend($graph_filename);
+	    if (($aux!="MINI") && ($ret!=FALSE)) rrdtool_add_legend($graph_filename, $sizey);
 
 	    if ($aux != "get_graph_data") 	//if we were not asked for the extra data (currently 95 percentile data points)
 		unset ($other_data);		// do not return it.
@@ -246,25 +263,28 @@
 	}
     }
     
-    function rrdtool_add_legend ($file, $type = 3) {
+    function rrdtool_add_legend ($file, $sizey) {
 	$im = ImageCreateFromPNG($file);
-	if ($im) {
-	    switch ($type) {
-		case 1:  
-		    $legend = "http://jffnms.org JFFNMS";
-		    break;
-		case 2:
-		    $legend = "JFFNMS";
-		    break;
-		case 3:
-		    $legend = get_config_option("jffnms_site")." JFFNMS";
-		    break;
-	    }
-	    $legend = trim($legend);
-	    $len = strlen($legend)*7;
-	    $posy = round((imagesy($im)*(0.5))+($len*0.5))+43;
-	    ImageStringUP($im,3,imagesx($im)-15,$posy,$legend,ImageColorAllocate($im,150,150,150));
 
+	if ($im) {
+	
+	    if (get_config_option("rrdtool_version")=="1.0") { // RRDTool Version 1.0.x
+
+		$legend = get_config_option("jffnms_site")." JFFNMS";
+		$legend = trim($legend);
+	        $len = strlen($legend)*7;
+	        $posy = round((imagesy($im)*(0.5))+($len*0.5))+43;
+		ImageStringUP($im,3,imagesx($im)-15,$posy,$legend,ImageColorAllocate($im,150,150,150));
+	    
+	    } else {	//RRDTool Version 1.2.x (has their watermark bigger, so, not to overlap we changed our watermark format)
+	
+		$legend = get_config_option("jffnms_site");
+	        $legend1 = "JFFNMS";
+		$posy = $sizey+25;
+	        ImageStringUP($im,3,imagesx($im)-26,$posy,$legend ,ImageColorAllocate($im,150,150,150));
+		ImageStringUP($im,3,imagesx($im)-16,$posy,$legend1,ImageColorAllocate($im,100,100,100));
+	    }
+	    
 	    ImagePNG($im,$file);
 	    ImageDestroy($im);
 	}
