@@ -1,21 +1,18 @@
 <?
-    function user_add ($username,$default_profile = 1){ 
-	if ($username) {
-    	    $query="Insert into auth (usern) VALUES ('$username')";
-    	    //echo "$query\n";
-    	    $result = db_query ($query) or die ("Query failed - USERADD-1 - ".db_error());
-    	    $user_id = db_insert_id();
+/* This file is part of JFFNMS
+ * Copyright (C) <2002-2005> Javier Szyszlican <javier@szysz.com>
+ * This program is licensed under the GNU GPL, full terms in the LICENSE file
+ */
+    function user_add ($username) {
 
-    	    if ($default_profile==1) {
-		$query = "select id,default_value from profiles_options where use_default = 1"; //FIXME order
-    		$result = db_query($query) or die ("Query Filed - USERADD-2 - ".db_error()); 
+	$user_id = db_insert("auth", array("usern"=>$username));
+
+	$query = "SELECT id, default_value FROM profiles_options WHERE use_default = 1"; //FIXME order
+	$result = db_query($query) or die ("Query Filed - user_add() - profile - ".db_error()); 
+
+	while ($row = db_fetch_array($result)) //add every default option to the user profile
+	    profile_add_option($user_id,$row["id"]);
 
-		while ($row = db_fetch_array($result)) { //add every default option to the user profile
-		    profile_add_option($user_id,$row["id"]);
-		    //profile_modify_value($user_id,$row["id"],$row["default_value"]);
-		}
-	    }
-	}		
 	return $user_id;
     }
 
@@ -75,11 +72,16 @@
 	
 	if (!is_array($where_special)) $where_special = array();
 
-        return get_db_list("auth",$ids, "*", //table,ids,fields	
-		array_merge(
-		    array(array("id",">",1)),
-		    $where_special), //where
-		array(array("usern","asc")) ); //order 
+        return get_db_list(
+	    "auth",
+	    $ids, 
+	    array(
+	    "*",
+	    "old_passwd"=>"passwd"),
+	    array_merge(
+	        array(array("id",">",1)),
+	        $where_special), //where
+	    array(array("usern","asc")) ); //order 
     }
 
 ?>
