@@ -91,9 +91,9 @@
     
     function clean_url($extra_vars = array(),$no_vars = array()) {
 	if ($GLOBALS["_GET"]) 
-	    $REQUEST_URI_VARS = array_merge($GLOBALS["_GET"],$GLOBALS["_POST"],$extra_vars); //suport for PHP 4.1.0 and older
+	    $REQUEST_URI_VARS = @array_merge($GLOBALS["_GET"],$GLOBALS["_POST"],$extra_vars); //suport for PHP 4.1.0 and older
     	else 
-	    $REQUEST_URI_VARS = array_merge($GLOBALS["HTTP_GET_VARS"],$GLOBALS["HTTP_POST_VARS"],$extra_vars);
+	    $REQUEST_URI_VARS = @array_merge($GLOBALS["HTTP_GET_VARS"],$GLOBALS["HTTP_POST_VARS"],$extra_vars);
 
 	foreach ($no_vars as $delete)
 	    unset($REQUEST_URI_VARS[$delete]);
